==> apache-wicket-9.22.0.tar.gz: apache-wicket-9.22.0/wicket-core/src/main/java/org/apache/wicket/response/StringResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.response;

import org.apache.wicket.request.Response;
import org.apache.wicket.util.string.AppendingStringBuffer;


/**
 * Response object that writes to a StringWriter. If the StringResponse is later converted to a
 * String via toString(), the output which was written to the StringResponse will be returned as a
 * String.
 * 
 * @author Jonathan Locke
 */
public class StringResponse extends Response
{

	private static final int DEFAULT_INITIAL_CAPACITY = 128;

	/** StringWriter to write to */
	protected final AppendingStringBuffer out;

	/**
	 * Constructor
	 */
	public StringResponse()
	{
		this(DEFAULT_INITIAL_CAPACITY);
	}

	/**
	 * Constructor
	 * 
	 * @param initialCapacity
	 *            the initial capacity of the internal buffer
	 */
	public StringResponse(int initialCapacity)
	{
		out = new AppendingStringBuffer(initialCapacity);
	}

	/**
	 * @see org.apache.wicket.request.Response#write(CharSequence)
	 */
	@Override
	public void write(final CharSequence string)
	{
		out.append(string);
	}

	/**
	 * @see org.apache.wicket.request.Response#reset()
	 */
	@Override
	public void reset()
	{
		out.clear();
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return out.toString();
	}

	/**
	 * @return The internal buffer directly as a {@link CharSequence}
	 */
	public CharSequence getBuffer()
	{
		return out;
	}

	@Override
	public void write(byte[] array)
	{
		throw new UnsupportedOperationException();
	}

	@Override
	public void write(byte[] array, int offset, int length)
	{
		throw new UnsupportedOperationException();
	}

	@Override
	public String encodeURL(CharSequence url)
	{
		return url != null ? url.toString() : null;
	}

	@Override
	public Object getContainerResponse()
	{
		return null;
	}
}

==> apache-wicket-10.8.0.tar.gz: apache-wicket-10.8.0/wicket-core/src/main/java/org/apache/wicket/response/StringResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.response;

import org.apache.wicket.request.Response;
import org.apache.wicket.util.string.AppendingStringBuffer;


/**
 * Response object that writes to an AppendingStringBuffer. If the StringResponse is later converted to a
 * String via toString(), the output which was written to the StringResponse will be returned as a
 * String.
 * 
 * @author Jonathan Locke
 */
public class StringResponse extends Response
{

	private static final int DEFAULT_INITIAL_CAPACITY = 128;

	/** Initial capacity of the buffer */
	private final int initialCapacity;

	/** Buffer to write to */
	private AppendingStringBuffer out;

	public StringResponse()
	{
		this(DEFAULT_INITIAL_CAPACITY);
	}

	public StringResponse(int initialCapacity)
	{
		this.initialCapacity = initialCapacity;
	}

	/**
	 * @see Response#write(CharSequence)
	 */
	@Override
	public void write(final CharSequence string)
	{
		if (out == null)
		{
			out = new AppendingStringBuffer(initialCapacity);
		}
		out.append(string);
	}

	/**
	 * @see Response#reset()
	 */
	@Override
	public void reset()
	{
		if (out != null)
		{
			out.clear();
		}
	}

	/**
	 * @see Object#toString()
	 */
	@Override
	public String toString()
	{
		return getBuffer().toString();
	}

	/**
	 * @return The internal buffer as a {@link CharSequence} or an empty string if no content has
	 *         been written to the response
	 */
	public CharSequence getBuffer()
	{
		return out != null ? out : "";
	}

	@Override
	public void write(byte[] array)
	{
		throw new UnsupportedOperationException();
	}

	@Override
	public void write(byte[] array, int offset, int length)
	{
		throw new UnsupportedOperationException();
	}

	@Override
	public String encodeURL(CharSequence url)
	{
		return url != null ? url.toString() : null;
	}

	@Override
	public Object getContainerResponse()
	{
		return null;
	}
}
